@@ -116,7 +116,7 @@ QEMU_TEMPLATE_PROPERTIES = {
     "hda_disk_interface": {
         "description": "QEMU hda interface",
         "enum": ["ide", "sata", "nvme", "scsi", "sd", "mtd", "floppy", "pflash", "virtio", "none"],
-        "default": "ide"
+        "default": "none"
     },
     "hdb_disk_image": {
         "description": "QEMU hdb disk image path",
@@ -126,7 +126,7 @@ QEMU_TEMPLATE_PROPERTIES = {
     "hdb_disk_interface": {
         "description": "QEMU hdb interface",
         "enum": ["ide", "sata", "nvme", "scsi", "sd", "mtd", "floppy", "pflash", "virtio", "none"],
-        "default": "ide"
+        "default": "none"
     },
     "hdc_disk_image": {
         "description": "QEMU hdc disk image path",
@@ -136,7 +136,7 @@ QEMU_TEMPLATE_PROPERTIES = {
     "hdc_disk_interface": {
         "description": "QEMU hdc interface",
         "enum": ["ide", "sata", "nvme", "scsi", "sd", "mtd", "floppy", "pflash", "virtio", "none"],
-        "default": "ide"
+        "default": "none"
     },
     "hdd_disk_image": {
         "description": "QEMU hdd disk image path",
@@ -146,7 +146,7 @@ QEMU_TEMPLATE_PROPERTIES = {
     "hdd_disk_interface": {
         "description": "QEMU hdd interface",
         "enum": ["ide", "sata", "nvme", "scsi", "sd", "mtd", "floppy", "pflash", "virtio", "none"],
-        "default": "ide"
+        "default": "none"
     },
     "cdrom_image": {
         "description": "QEMU cdrom image path",
@@ -183,6 +183,11 @@ QEMU_TEMPLATE_PROPERTIES = {
         "type": "boolean",
         "default": True
     },
+    "create_config_disk": {
+        "description": "Automatically create a config disk on HDD disk interface (secondary slave)",
+        "type": "boolean",
+        "default": False
+    },
     "on_close": {
         "description": "Action to execute on the VM is closed",
         "enum": ["power_off", "shutdown_signal", "save_vm_state"],
