@@ -669,13 +669,13 @@ async def test_qemu_template_create(controller_api):
                          "default_name_format": "{name}-{0}",
                          "first_port_name": "",
                          "hda_disk_image": "IOSvL2-15.2.4.0.55E.qcow2",
-                         "hda_disk_interface": "ide",
+                         "hda_disk_interface": "none",
                          "hdb_disk_image": "",
-                         "hdb_disk_interface": "ide",
+                         "hdb_disk_interface": "none",
                          "hdc_disk_image": "",
-                         "hdc_disk_interface": "ide",
+                         "hdc_disk_interface": "none",
                          "hdd_disk_image": "",
-                         "hdd_disk_interface": "ide",
+                         "hdd_disk_interface": "none",
                          "initrd": "",
                          "kernel_command_line": "",
                          "kernel_image": "",
